using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Runtime.InteropServices;

namespace rfid
{
  class GIS_URW_API
  {
    public delegate int AutoReadCallback([MarshalAsAttribute(UnmanagedType.LPStr)] string pData, int Len);

    // Get Library Version
    [DllImport("TS_URW_SDK64.dll")] 
    public static extern int TSURW_LibVersion();

    [DllImport("TS_URW_SDK64.dll")] 
    public static extern int TSURW_IsVirtualComInstalled();

    // Get Names of all USB Devices connected, only valid devices are listed
    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_GetUSBDeviceNames(SByte[] NamenListe, int nBufferSize);

    // Get Names of all USB Devices connected, all devices from GiS are listed
    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_GetUSBDeviceNamesEx(SByte[] NamenListe, int nBufferSize);

    // Get Names of all COM Ports available, not tested if there is a device at the port connected.
    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_GetCOMDeviceNames(SByte[] NamenListe, int nBufferSize);

    // Get Names of all valid LAN devices found in same subnet
    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_GetLanDeviceNames(SByte[] NamenListe, int nBufferSize);

    // Get Names of all LAN devices found even in other subnets
    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_GetLanDeviceNamesEx(SByte[] Buffer, int nBufferSize);

    // Change IP Address of LAN device
    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_ChangeLanIPAddress(SByte[] OldAddress, SByte[] NewAddress, SByte[] IPMask);

    // Change IP Address and Gateway of LAN device
    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_ChangeLanIPAddressEx(SByte[] OldAddress, SByte[] NewAddress, SByte[] IPMask, SByte[] GatewayAddress);

    // Get IP Address and Gateway of LAN device
    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_GetLanIPAddressEx(SByte[] strName, SByte[] Address, SByte[] IPMask, SByte[] GatewayAddress);

    // Check if specific LAN device is available
    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_IsLanDeviceAvailable(string Address);

    // Open LAN Device for configuration
    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_LanConfigOpen(string strName);

    // Set Configuration Record of LAN device, use with care!
    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_LanConfigGet(int nHandle, int RecordNr, Byte[] pData, int Len);

    // Get Configuration Record of LAN device
    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_LanConfigSet(int nHandle, int RecordNr, Byte[] pData, int Len);

    // Close LAN device configuration.
    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_LanConfigClose(int nHandle, int Reset);

    // Read Configuration of USB HID device
    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_HIDConfigRead(int PortHandle, Byte[] pSendBuf, int SendBufLen, Byte[] pRecvBuf, int RecvBufLen);
    // Write Configuration to USB HID device
    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_HIDConfigWrite(int PortHandle, Byte[] pSendBuf, int SendBufLen);

    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_Open(string Name, int Baudrate, int ParityMode, int Timeout);
    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_Close(int handle);
    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_KeepAppActive(int handle, int bActive);

    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_SetReaderAdresse(int handle, int Adresse);

    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_StartAutoRead(int handle, int TermChar, AutoReadCallback cbFunction);
    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_StopAutoRead(int handle);

    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_GetDeviceVersion(int handle, Byte[] pDevVer, int VerLen, Byte[] pDevName, int NameLen);
    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_IsUSB(int handle);
    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_SetBaudrate(int handle, int Baudrate, int ParityMode);
    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_SetReaderMode(int handle, int mode);
    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_SetRF(int handle, int OnOff);
    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_GetLastError(int handle);
    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_SetIO(int handle, int Maske, int Daten);
    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_ReadIO(int handle, int[] pDaten);
    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_TestIO(int handle, int[] pTestwert);

    [DllImport("TS_URW_SDK64.dll")]
		public static extern int TSURW_SetLED(int handle, int red, int green, int yellow);
    [DllImport("TS_URW_SDK64.dll")]
		public static extern int TSURW_Beep(int handle);
		
    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_ReadSerialNumber(int handle, Byte[] pSerial, int Buflen);
    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_SetConfig(int handle, Byte[] pConfig, int ConfigLen);
    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_GetConfig(int handle, Byte[] pConfig, int ConfigLen);
    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_SetDefault(int handle);
    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_SetCommunicationMode(int handle, int Mode);

    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_RawWrite(int handle, Byte[] pBuffer, int BufLen);
    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_RawRead(int handle, Byte[] pBuffer, int BufLen);
    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_Transfer(int PortHandle, int Cmd, Byte[] pSendBuf, int SendBufLen, Byte[] pRecvBuf, int RecvBufLen);

    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_ReadRegister  (int handle, int Register, int []pVal);
    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_WriteRegister (int handle, int Register, int Val);
    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_WriteRegister3(int handle, int Register, int Val);

    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_Inventory(int PortHandle, int nInventoryType, Byte[] pBuffer, int BufLen);
    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_InventoryRSSI(int PortHandle, int nInventoryType, Byte[] pBuffer, int BufLen);
    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_ReadData(int handle, int MemType, int nStartByte, Byte[] pBuffer, int BufLen);
    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_ReadAllData(int handle, int MemType, int nStartByte, Byte[] pBuffer, int BufLen);
    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_ReadDataPW (int handle, int MemType, int nStartByte, Byte[] pPassword, Byte[] pBuffer, int BufLen);
    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_WriteData(int handle, int MemType, int nStartByte, Byte[] pBuffer, int BufLen);
    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_WriteDataPW(int handle, int MemType, int nStartByte, Byte[] pPassword, Byte[] pBuffer, int BufLen);
    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_Select(int PortHandle, Byte[] pUID, int UIDLen);

    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_Lock   (int handle, int MemType, int LockType, Byte[] pPassword);
    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_KillTag(int handle, int RecomState, Byte[] pPassword);

    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_WriteParam(int handle, Byte[] pBuffer, int BufLen);
    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_ReadParam(int handle, Byte[] pBuffer, int BufLen);
    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_WritePrefix(int handle, Byte[] pBuffer, int BufLen);
    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_ReadPrefix(int handle, Byte[] pBuffer, int BufLen);
    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_WriteSuffix(int handle, Byte[] pBuffer, int BufLen);
    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_ReadSuffix(int handle, Byte[] pBuffer, int BufLen);
    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_WriteTermix(int handle, Byte[] pBuffer, int BufLen);
    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_ReadTermix(int handle, Byte[] pBuffer, int BufLen);
    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_WritePostcode(int handle, Byte[] pBuffer, int BufLen);
    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_ReadPostcode(int handle, Byte[] pBuffer, int BufLen);
    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_WriteReadModeParam(int handle, Byte[] pBuffer, int BufLen);
    [DllImport("TS_URW_SDK64.dll")]
    public static extern int TSURW_ReadReadModeParam(int handle, Byte[] pBuffer, int BufLen);

    
    public GIS_URW_API()
    {
    }
  }
}
